@@ -1,7 +1,7 @@
 from django.core.validators import MinValueValidator
 from django.forms import (
     CharField,
-    IntegerField,
+    FloatField,
 )
 from django.urls import reverse_lazy
 
@@ -32,7 +32,7 @@ class PartitionForm(NetBoxModelForm):
         label="Device",
         help_text="The device name e.g. /dev/sdc1",
     )
-    size = IntegerField(
+    size = FloatField(
         label="Size (GB)",
         help_text="The size of the partition e.g. 25",
         validators=[MinValueValidator(1)],
@@ -78,7 +78,7 @@ class PartitionFilterForm(NetBoxModelFilterSetForm):
         label="Device",
         help_text="The device name e.g. /dev/sdc1",
     )
-    size = IntegerField(
+    size = FloatField(
         required=False,
         label="Size (GB)",
         help_text="The size of the partition e.g. 25",
@@ -110,7 +110,7 @@ class PartitionImportForm(NetBoxModelImportForm):
         label="Device",
         help_text="The device name e.g. /dev/sdc1",
     )
-    size = IntegerField(
+    size = FloatField(
         required=True,
         label="Size (GB)",
         help_text="The size of the partition e.g. 25",
@@ -158,7 +158,7 @@ class PartitionBulkEditForm(NetBoxModelBulkEditForm):
         label="Device",
         help_text="The device name e.g. /dev/sdc1",
     )
-    size = IntegerField(
+    size = FloatField(
         required=True,
         label="Size (GB)",
         help_text="The size of the partition e.g. 25",
