@@ -26,7 +26,7 @@ class Migration(migrations.Migration):
                 ("virtual_machine",
                  models.ForeignKey(blank=True, null=True, on_delete=models.deletion.CASCADE,
                                    related_name="virtual_machine_drive", to="virtualization.virtualmachine")),
-                ("size", models.PositiveIntegerField()),
+                ("size", models.FloatField()),
                 ("identifier", models.CharField(max_length=255)),
                 ("description", models.CharField(max_length=255)),
             ],
@@ -52,7 +52,7 @@ class Migration(migrations.Migration):
                  models.ForeignKey(on_delete=models.deletion.PROTECT, related_name="drive_partition",
                                    to="netbox_storage.drive")),
                 ("device", models.CharField(max_length=255)),
-                ("size", models.PositiveIntegerField()),
+                ("size", models.FloatField()),
                 ("type", models.CharField(max_length=255)),
                 ("description", models.CharField(max_length=255)),
             ],
@@ -151,7 +151,7 @@ class Migration(migrations.Migration):
                 ("fs",
                  models.ForeignKey(blank=True, null=True, on_delete=models.deletion.CASCADE, related_name='fs_linux',
                                    to='netbox_storage.filesystem')),
-                ("size", models.PositiveIntegerField()),
+                ("size", models.FloatField()),
                 ("description", models.CharField(max_length=255)),
             ],
             options={
