@@ -34,11 +34,16 @@ class RelatedDrives(PluginTemplateExtension):
             lvm_list.append(LVMModel(lv.lv_name, lv.path, lv.fs, lv.size, lv.vg.vg_name))
             physical_volumes = PhysicalVolume.objects.all()
             physical_volume_list = []
+            partition_list = []
+            logger.warning(f'vor for {physical_volumes}')
             for physical_volume in physical_volumes:
+                logger.warning(f'nach for {physical_volume}')
                 if physical_volume.vg == lv.vg:
-                    physical_volume_list.append(physical_volume.pv_name)
+                    physical_volume_list.append(physical_volume)
                     lvm_model = lvm_list[-1]
                     lvm_model.pv_list = physical_volume_list
+                    partition_list.append(physical_volume.partition)
+                    lvm_model.partition_list = partition_list
             #         partitions = Partition.objects.all()
             #         partition_list = []
             #         for partition in partitions:
